@@ -171,9 +171,9 @@ class Accum2(GroupByOps, FastArray):
         self.grouping = None
         del self._cat_cols
         del self._cat_rows
-        if self._dataset: del self._dataset
-        if self._gb_keychain: del self._gb_keychain
-        if self._ylabel: del self._ylabel
+        if self._dataset is not None: del self._dataset
+        if self._gb_keychain is not None: del self._gb_keychain
+        if self._ylabel is not None: del self._ylabel
 
     # ------------------------------------------------------------
     @property
@@ -743,8 +743,8 @@ class Accum2(GroupByOps, FastArray):
                 im = im[1:,:]
 
             # create row and col mask, init to all True
-            boolmaskY = ones(len(totalsY), dtype=np.bool)
-            boolmaskX = ones(len(totalsX), dtype=np.bool)
+            boolmaskY = ones(len(totalsY), dtype=bool)
+            boolmaskX = ones(len(totalsX), dtype=bool)
 
             # do both horizontal and vertical calculations which are dirty
             newTotalsX, newTotalsY =  cls._apply_2d_operation(func, im, True)
