@@ -350,7 +350,13 @@ class TimeZone:
         'NYC'    : 'America/New_York',
         'DUBLIN' : 'Europe/Dublin',
         'GMT'    : 'GMT',
-        'UTC'    : 'GMT'
+        'UTC'    : 'UTC'
+    }
+    long_to_short_timezone_names = {
+        'America/New_York': 'NYC',
+        'Europe/Dublin': 'DUBLIN',
+        'UTC': 'UTC',
+        'GMT': 'GMT'
     }
     tz_error_msg = f"If constructing from strings specify a timezone in from_tz keyword. Valid options: {valid_timezones}. Example: dtn = DateTimeNano(['2018-12-13 10:30:00'], from_tz='NYC')"
 
@@ -437,10 +443,10 @@ class TimeZone:
         if cutoffs is None:
             cutoffs = self._dst_cutoffs
         if cutoffs is None:
-            return zeros(len(arr), dtype=np.bool)
+            return zeros(len(arr), dtype=bool)
 
-        #is_dst = (FastArray(np.searchsorted(DST_CUTOFFS, arr)) & 1).astype(np.bool)
-        #is_dst = (rc.BinsToCutsBSearch(arr, cutoffs, 0) & 1).astype(np.bool)
+        #is_dst = (FastArray(np.searchsorted(DST_CUTOFFS, arr)) & 1).astype(bool)
+        #is_dst = (rc.BinsToCutsBSearch(arr, cutoffs, 0) & 1).astype(bool)
 
         is_dst = (searchsorted(cutoffs, arr) & 1).astype(np.bool_)
         return is_dst
