@@ -63,7 +63,7 @@ array_sizes = [
 # these will break a lot of ufuncs because of division by zero, nans, etc.
 # TODO: add unit tests to make sure they break correctly
 numeric_types_with_invalid = {
-    'bool': FastArray([1, 0, 1, 0, 0, 1, 0, 1, 1, 1, 0, 1, 0, 1, 0], dtype=np.bool),
+    'bool': FastArray([1, 0, 1, 0, 0, 1, 0, 1, 1, 1, 0, 1, 0, 1, 0], dtype=bool),
     'int8': FastArray(
         [
             26,
@@ -268,7 +268,7 @@ numeric_types_with_invalid = {
 with warnings.catch_warnings():
     warnings.simplefilter('ignore', category=UserWarning)
     all_types = {
-        'bool': FastArray([1, 0, 1, 0, 0, 1, 0, 1, 1, 1, 0, 1, 0, 1, 0], dtype=np.bool),
+        'bool': FastArray([1, 0, 1, 0, 0, 1, 0, 1, 1, 1, 0, 1, 0, 1, 0], dtype=bool),
         'int8': FastArray(
             [
                 26,
@@ -1489,7 +1489,18 @@ class FastArray_Test(unittest.TestCase):
         assert 0 == np.sum(rt.FA([], dtype=np.int32), dtype=np.int64)
         assert 0 == np.nansum(rt.FA([], dtype=np.uint8), dtype=np.int32)
         assert 0 == np.nansum(rt.FA([], dtype=np.float64), dtype=np.float64)
-        
+
+    def test_view_unspecified_type(self) -> None:
+        """Test how FastArray.view() behaves when an output type is not explicitly specified."""
+        arr = FastArray([6, 8, 10, 10, 0, 5, 2], dtype=np.uint32)
+        arr.set_name(f"my_test_{type(arr).__name__}")
+        arr_view = arr.view()
+        self.assertEqual(type(arr), type(arr_view))
+        self.assertEqual(arr.shape, arr_view.shape)
+        self.assertFalse(arr_view.flags.owndata)
+        self.assertEqual(arr.get_name(), arr_view.get_name())
+        self.assertTrue((arr == arr_view).all())
+
 # TODO: Extend the tests in the TestFastArrayNanmax / TestFastArrayNanmin classes below to cover the following cases:
 #   * non-array inputs (e.g. a list or set or scalar)
 #   * other FastArray subclass, e.g. Date
@@ -1650,5 +1661,22 @@ def test_array_function_empty_like(np_callable, fast_array):
     assert actual.shape == fast_array.shape, 'shape mismatch'
 
 
+@pytest.mark.xfail(reason='Known bug as of riptable 1.1.0.')
+@pytest.mark.parametrize('as_unicode', [False, True])
+def test_ctor_from_str_obj_array_with_None(as_unicode: bool) -> None:
+    # Create a numpy object array containing some None values.
+    input = np.array(['abc', None, 'ghi', 'jkl', None, 'abc', 'ghi'], dtype=object)
+    none_mask = input == None
+
+    # Create the FastArray from the input.
+    result = FastArray(input, dtype=str, unicode=as_unicode)
+    assert input.shape == result.shape
+
+    # The expected output; specifically, make sure the None values in the input
+    # are converted to the riptable 'invalid' for the output array type.
+    none_results = result[none_mask]
+    assert_array_equal(none_results, rt.full(none_results.shape, result.inv, dtype=none_results.dtype))
+
+
 if __name__ == "__main__":
     tester = unittest.main()
