@@ -186,34 +186,32 @@ class TestRTNumpy:
     def test_sample(self):
         # Test Dataset.sample
         ds = rt.Dataset({'num': [1, 2, 3, 4, 5], 'str': ['ab', 'bc', 'cd', 'de', 'ef']})
-        np.random.seed(1)
-        ds_sample = ds.sample(3, rt.FA([True, True, True, False, True]))
-        ds_sample_expected = rt.Dataset({'num': [1, 3, 5], 'str': ['ab', 'cd', 'ef']})
-        assert (ds_sample_expected == ds_sample).all(axis=None)
+        ds_sample = ds.sample(3, rt.FA([True, True, True, False, True]), seed=1)
+        ds_sample_expected = rt.Dataset({'num': [1, 2, 5], 'str': ['ab', 'bc', 'ef']})
+        assert ds_sample.keys() == ds_sample_expected.keys()
+        for col_name in ds_sample_expected.keys():
+            assert_array_equal(ds_sample_expected[col_name], ds_sample[col_name], err_msg=f"Column '{col_name}' differs.")
 
         # Test FastArray.sample
         fa = rt.FA([1, 2, 3, 4, 5])
-        np.random.seed(1)
-        fa_sample = fa.sample(2, rt.FA([False, True, True, False, True]))
-        fa_sample_expected = rt.FA([2, 5])
-        assert (fa_sample_expected == fa_sample).all(axis=None)
+        fa_sample = fa.sample(2, rt.FA([False, True, True, False, True]), seed=1)
+        fa_sample_expected = rt.FA([2, 3])
+        assert_array_equal(fa_sample_expected, fa_sample)
 
         # Test overflow
-        fa_sample = fa.sample(10, rt.FA([False, True, False, False, True]))
+        fa_sample = fa.sample(10, rt.FA([False, True, False, False, True]), seed=1)
         fa_sample_expected = rt.FA([2, 5])
-        assert (fa_sample_expected == fa_sample).all(axis=None)
+        assert_array_equal(fa_sample_expected, fa_sample)
 
         # Test no filter
-        np.random.seed(1)
-        fa_sample = fa.sample(2)
+        fa_sample = fa.sample(2, seed=1)
         fa_sample_expected = rt.FA([2, 3])
-        assert (fa_sample_expected == fa_sample).all(axis=None)
+        assert_array_equal(fa_sample_expected, fa_sample)
 
         # Test fancy index
-        np.random.seed(1)
-        fa_sample = fa.sample(2, rt.FA([1, 3, 4]))
-        fa_sample_expected = rt.FA([2, 5])
-        assert (fa_sample_expected == fa_sample).all(axis=None)
+        fa_sample = fa.sample(2, rt.FA([1, 3, 4]), seed=1)
+        fa_sample_expected = rt.FA([2, 4])
+        assert_array_equal(fa_sample_expected, fa_sample)
 
     def test_hstack_returns_same_type(self):
         # Create some instances of the same derived array type.
@@ -234,6 +232,46 @@ class TestRTNumpy:
         assert type(result) == array_type
         assert len(result) == total_len
 
+class TestHStackAny:
+    """Tests for the rt.hstack_any (a.k.a. rt.stack_rows) function."""
+
+    _fa1 = rt.FastArray([100, 200])
+    _fa2 = rt.FastArray([111, 222])
+    _dtn1 = rt.DateTimeNano('2021-10-12 01:02:03', from_tz='UTC')
+    _dtn2 = rt.DateTimeNano('1980-03-04 13:14:15', from_tz='UTC')
+    _ts1 = _dtn1 - _dtn2
+    _ts2 = _dtn2 - _dtn1
+    _ds1 = rt.Dataset({'a': 11})
+    _ds2 = rt.Dataset({'b': 22})
+    _pds1 = rt.PDataset(_ds1)
+    _pds2 = rt.PDataset(_ds2)
+
+    @pytest.mark.parametrize(
+        "inputs,expected",
+        [
+            pytest.param([_fa1, _fa2], rt.FastArray, id='FastArray,FastArray'),
+            pytest.param([_dtn1, _dtn2], rt.DateTimeNano, id='DateTimeNano,DateTimeNano'),
+            pytest.param([_dtn1, _dtn2], rt.DateTimeNano, id='DateTimeNano,DateTimeNano'),
+            pytest.param([_ts1, _ts2], rt.TimeSpan, id='TimeSpan,TimeSpan'),
+            pytest.param([_ds1, _ds2], rt.Dataset, id='Dataset,Dataset'),
+            pytest.param([_pds1, _pds2], None, id='PDataset,PDataset'), # notyet
+
+            pytest.param([_dtn1, _ts2], None, id='DateTimeNano,TimeSpan'), # neither is base
+            pytest.param([_fa1, _dtn2], rt.FastArray, id='FastArray,DateTimeNano'),
+            pytest.param([_ts1, _fa2], rt.FastArray, id='TimeSpan,FastArray'),
+
+            pytest.param([_ds1, _pds2], rt.Dataset, id='Dataset,PDataset'),
+            pytest.param([_pds1, _ds2], rt.Dataset, id='PDataset,Dataset'),
+            pytest.param([_fa1, _ds2], None, id='FastArray,Dataset'),
+        ],
+    )
+    def test_hstack_any(self, inputs, expected):
+        if expected is None:
+            with pytest.raises(Exception):
+                rt.hstack_any(inputs)
+        else:
+            result = rt.hstack_any(inputs)
+            assert type(result) == expected
 
 class TestMaximum:
     """Tests for the rt.maximum function."""
@@ -370,7 +408,7 @@ class TestNanmax:
 
         # The result should either be a Python string, a numpy string scalar, or a Categorical scalar (if we implement one).
         is_py_str = isinstance(result, (bytes, str))
-        is_np_scalar = isinstance(result, np.str)
+        is_np_scalar = isinstance(result, (np.bytes_, np.str_))
         is_rt_cat = isinstance(result, rt.Categorical)
         assert is_py_str or is_np_scalar or is_rt_cat
 
@@ -448,7 +486,7 @@ class TestNanmin:
 
         # The result should either be a Python string, a numpy string scalar, or a Categorical scalar (if we implement one).
         is_py_str = isinstance(result, (bytes, str))
-        is_np_scalar = isinstance(result, np.str)
+        is_np_scalar = isinstance(result, (np.bytes_, np.str_))
         is_rt_cat = isinstance(result, rt.Categorical)
         assert is_py_str or is_np_scalar or is_rt_cat
 
